@@ -1,5 +1,3 @@
-#!/usr/pkg/bin/python3.12
-#
 # Copyright (C) 2009-2020 the sqlparse authors and contributors
 # <see AUTHORS file>
 #
@@ -36,10 +34,13 @@ def create_parser():
         prog='sqlformat',
         description='Format FILE according to OPTIONS. Use "-" as FILE '
                     'to read from stdin.',
-        usage='%(prog)s  [OPTIONS] FILE, ...',
+        usage='%(prog)s [OPTIONS] FILE [FILE ...]',
     )
 
-    parser.add_argument('filename')
+    parser.add_argument(
+        'filename',
+        nargs='+',
+        help='file(s) to format (use "-" for stdin)')
 
     parser.add_argument(
         '-o', '--outfile',
@@ -47,6 +48,13 @@ def create_parser():
         metavar='FILE',
         help='write output to FILE (defaults to stdout)')
 
+    parser.add_argument(
+        '--in-place',
+        dest='inplace',
+        action='store_true',
+        default=False,
+        help='format files in-place (overwrite existing files)')
+
     parser.add_argument(
         '--version',
         action='version',
@@ -60,7 +68,7 @@ def create_parser():
         dest='keyword_case',
         choices=_CASE_CHOICES,
         help='change case of keywords, CHOICE is one of {}'.format(
-            ', '.join('"{}"'.format(x) for x in _CASE_CHOICES)))
+            ', '.join(f'"{x}"' for x in _CASE_CHOICES)))
 
     group.add_argument(
         '-i', '--identifiers',
@@ -68,7 +76,7 @@ def create_parser():
         dest='identifier_case',
         choices=_CASE_CHOICES,
         help='change case of identifiers, CHOICE is one of {}'.format(
-            ', '.join('"{}"'.format(x) for x in _CASE_CHOICES)))
+            ', '.join(f'"{x}"' for x in _CASE_CHOICES)))
 
     group.add_argument(
         '-l', '--language',
@@ -157,15 +165,21 @@ def create_parser():
 
 def _error(msg):
     """Print msg and optionally exit with return code exit_."""
-    sys.stderr.write('[ERROR] {}\n'.format(msg))
+    sys.stderr.write(f'[ERROR] {msg}\n')
     return 1
 
 
-def main(args=None):
-    parser = create_parser()
-    args = parser.parse_args(args)
+def _process_file(filename, args):
+    """Process a single file with the given formatting options.
 
-    if args.filename == '-':  # read from stdin
+    Returns 0 on success, 1 on error.
+    """
+    # Check for incompatible option combinations first
+    if filename == '-' and args.inplace:
+        return _error('Cannot use --in-place with stdin')
+
+    # Read input
+    if filename == '-':  # read from stdin
         wrapper = TextIOWrapper(sys.stdin.buffer, encoding=args.encoding)
         try:
             data = wrapper.read()
@@ -173,27 +187,34 @@ def main(args=None):
             wrapper.detach()
     else:
         try:
-            with open(args.filename, encoding=args.encoding) as f:
+            with open(filename, encoding=args.encoding) as f:
                 data = ''.join(f.readlines())
         except OSError as e:
-            return _error(
-                'Failed to read {}: {}'.format(args.filename, e))
+            return _error(f'Failed to read {filename}: {e}')
 
+    # Determine output destination
     close_stream = False
-    if args.outfile:
+    if args.inplace:
+        try:
+            stream = open(filename, 'w', encoding=args.encoding)
+            close_stream = True
+        except OSError as e:
+            return _error(f'Failed to open {filename}: {e}')
+    elif args.outfile:
         try:
             stream = open(args.outfile, 'w', encoding=args.encoding)
             close_stream = True
         except OSError as e:
-            return _error('Failed to open {}: {}'.format(args.outfile, e))
+            return _error(f'Failed to open {args.outfile}: {e}')
     else:
         stream = sys.stdout
 
+    # Format the SQL
     formatter_opts = vars(args)
     try:
         formatter_opts = sqlparse.formatter.validate_options(formatter_opts)
     except SQLParseError as e:
-        return _error('Invalid options: {}'.format(e))
+        return _error(f'Invalid options: {e}')
 
     s = sqlparse.format(data, **formatter_opts)
     stream.write(s)
@@ -201,3 +222,25 @@ def main(args=None):
     if close_stream:
         stream.close()
     return 0
+
+
+def main(args=None):
+    parser = create_parser()
+    args = parser.parse_args(args)
+
+    # Validate argument combinations
+    if len(args.filename) > 1:
+        if args.outfile:
+            return _error('Cannot use -o/--outfile with multiple files')
+        if not args.inplace:
+            return _error('Multiple files require --in-place flag')
+
+    # Process all files
+    exit_code = 0
+    for filename in args.filename:
+        result = _process_file(filename, args)
+        if result != 0:
+            exit_code = result
+            # Continue processing remaining files even if one fails
+
+    return exit_code
